{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-I",
                        "itemSeparator": ","
                    },
                    "id": "#bwa-mem.cwl/min_std_max_min"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-k"
                    },
                    "doc": "-k INT        minimum seed length [19]",
                    "id": "#bwa-mem.cwl/minimum_seed_length"
                },
                {
                    "type": "string",
                    "id": "#bwa-mem.cwl/output_filename"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bwa-mem.cwl/reads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#bwa-mem.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "-t INT        number of threads [1]",
                    "id": "#bwa-mem.cwl/threads"
                }
            ],
            "stdout": "$(inputs.output_filename)",
            "baseCommand": [
                "bwa",
                "mem"
            ],
            "doc": "Usage: bwa mem [options] <idxbase> <in1.fq> [in2.fq]\n\nAlgorithm options:\n       -w INT        band width for banded alignment [100]\n       -d INT        off-diagonal X-dropoff [100]\n       -r FLOAT      look for internal seeds inside a seed longer than {-k} * FLOAT [1.5]\n       -y INT        seed occurrence for the 3rd round seeding [20]\n       -c INT        skip seeds with more than INT occurrences [500]\n       -D FLOAT      drop chains shorter than FLOAT fraction of the longest overlapping chain [0.50]\n       -W INT        discard a chain if seeded bases shorter than INT [0]\n       -m INT        perform at most INT rounds of mate rescues for each read [50]\n       -S            skip mate rescue\n       -P            skip pairing; mate rescue performed unless -S also in use\n       -e            discard full-length exact matches\n\nScoring options:\n\n       -A INT        score for a sequence match, which scales options -TdBOELU unless overridden [1]\n       -B INT        penalty for a mismatch [4]\n       -O INT[,INT]  gap open penalties for deletions and insertions [6,6]\n       -E INT[,INT]  gap extension penalty; a gap of size k cost '{-O} + {-E}*k' [1,1]\n       -L INT[,INT]  penalty for 5'- and 3'-end clipping [5,5]\n       -U INT        penalty for an unpaired read pair [17]\n\n       -x STR        read type. Setting -x changes multiple parameters unless overriden [null]\n                     pacbio: -k17 -W40 -r10 -A1 -B1 -O1 -E1 -L0  (PacBio reads to ref)\n                     ont2d: -k14 -W20 -r10 -A1 -B1 -O1 -E1 -L0  (Oxford Nanopore 2D-reads to ref)\n                     intractg: -B9 -O16 -L5  (intra-species contigs to ref)\n\nInput/output options:\n\n       -p            smart pairing (ignoring in2.fq)\n       -R STR        read group header line such as '@RG\\tID:foo\\tSM:bar' [null]\n       -H STR/FILE   insert STR to header if it starts with @; or insert lines in FILE [null]\n       -j            treat ALT contigs as part of the primary assembly (i.e. ignore <idxbase>.alt file)\n\n       -v INT        verbose level: 1=error, 2=warning, 3=message, 4+=debugging [3]\n       -T INT        minimum score to output [30]\n       -h INT[,INT]  if there are <INT hits with score >80% of the max score, output all in XA [5,200]\n       -a            output all alignments for SE or unpaired PE\n       -C            append FASTA/FASTQ comment to SAM output\n       -V            output the reference FASTA header in the XR tag\n       -Y            use soft clipping for supplementary alignments\n       -M            mark shorter split hits as secondary\n\n       -I FLOAT[,FLOAT[,INT[,INT]]]\n                     specify the mean, standard deviation (10% of the mean if absent), max\n                     (4 sigma from the mean if absent) and min of the insert size distribution.\n                     FR orientation only. [inferred]\n\nNote: Please read the man page for detailed description of the command line and options.\n",
            "id": "#bwa-mem.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#bwa-mem.cwl/output"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Coinami",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "First strand reads from Illumina Sequence",
                    "id": "#main/reads_1"
                },
                {
                    "type": "File",
                    "doc": "Second strand reads from Illumina Sequence",
                    "id": "#main/reads_2"
                },
                {
                    "type": "File",
                    "doc": "Reference file to start processing",
                    "id": "#main/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "Index of final output",
                    "outputSource": "#main/alignment_5/index",
                    "id": "#main/indexed_output"
                },
                {
                    "type": "File",
                    "doc": "Final output after removing duplicates",
                    "outputSource": "#main/alignment_4/rmdup",
                    "id": "#main/output"
                }
            ],
            "steps": [
                {
                    "run": "#bwa-mem.cwl",
                    "in": [
                        {
                            "default": "output.sam",
                            "id": "#main/alignment_1/output_filename"
                        },
                        {
                            "source": [
                                "#main/reads_1",
                                "#main/reads_2"
                            ],
                            "id": "#main/alignment_1/reads"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/alignment_1/reference"
                        }
                    ],
                    "out": [
                        "#main/alignment_1/output"
                    ],
                    "id": "#main/alignment_1"
                },
                {
                    "run": "#samtools-view.cwl",
                    "in": [
                        {
                            "source": "#main/alignment_1/output",
                            "id": "#main/alignment_2/input"
                        },
                        {
                            "default": true,
                            "id": "#main/alignment_2/isBam"
                        },
                        {
                            "default": "output.bam",
                            "id": "#main/alignment_2/output_name"
                        }
                    ],
                    "out": [
                        "#main/alignment_2/output"
                    ],
                    "id": "#main/alignment_2"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#main/alignment_2/output",
                            "id": "#main/alignment_3/input"
                        },
                        {
                            "default": "output.sorted",
                            "id": "#main/alignment_3/output_name"
                        }
                    ],
                    "out": [
                        "#main/alignment_3/sorted"
                    ],
                    "id": "#main/alignment_3"
                },
                {
                    "run": "#samtools-rmdup.cwl",
                    "in": [
                        {
                            "source": "#main/alignment_3/sorted",
                            "id": "#main/alignment_4/input"
                        },
                        {
                            "default": "output.rmdup.bam",
                            "id": "#main/alignment_4/output_name"
                        }
                    ],
                    "out": [
                        "#main/alignment_4/rmdup"
                    ],
                    "id": "#main/alignment_4"
                },
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/alignment_4/rmdup",
                            "id": "#main/alignment_5/input"
                        }
                    ],
                    "out": [
                        "#main/alignment_5/index"
                    ],
                    "id": "#main/alignment_5"
                }
            ],
            "doc": "Coinami is designed and developed by a small group in Bilkent University",
            "id": "#main",
            "http://schema.org/downloadUrl": "https://github.com/halilozercan/coinami-workflow/blob/master/coinami.cwl",
            "http://schema.org/codeRepository": "https://github.com/halilozercan/coinami-workflow",
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/name": "Halil Ozercan",
                "http://schema.org/email": "mailto:halil.ozercan@bilkent.edu.tr"
            }
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var new_ext = function() { var ext=inputs.bai?'.bai':inputs.csi?'.csi':'.bai'; return inputs.input.path.split('/').slice(-1)[0]+ext; };"
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": false,
                    "doc": "Generate BAI-format index for BAM files [default]\n",
                    "id": "#samtools-index.cwl/bai"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "doc": "Generate CSI-format index for BAM files\n",
                    "id": "#samtools-index.cwl/csi"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Input bam file.\n",
                    "id": "#samtools-index.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-m"
                    },
                    "doc": "Set minimum interval size for CSI indices to 2^INT [14]\n",
                    "id": "#samtools-index.cwl/interval"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(new_ext())"
                    },
                    "doc": "The index file",
                    "id": "#samtools-index.cwl/index"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.bai?'-b':inputs.csi?'-c':[])",
                    "position": 1
                },
                {
                    "valueFrom": "$(new_ext())",
                    "position": 3
                }
            ],
            "doc": "samtools-index.cwl is developed for CWL consortium\n",
            "id": "#samtools-index.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#samtools-metadata.yaml",
                "http://schema.org/name": "samtools",
                "http://schema.org/about": "A suite of programs for interacting with high-throughput sequencing data. It consists of three separate repositories: Samtools (Reading/writing/editing/indexing/viewing SAM/BAM/CRAM format), BCFtools (Reading/writing BCF2/VCF/gVCF files and calling/filtering/summarising SNP and short indel sequence variants) and HTSlib (A C library for reading/writing high-throughput sequencing data).\n",
                "http://schema.org/url": "http://www.htslib.org/",
                "http://schema.org/codeRepository": "https://github.com/samtools/samtools.git",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT",
                    "https://opensource.org/licenses/BSD-3-Clause"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "1.2-242-4d56437",
                    "http://schema.org/applicationCategory": "commandline tool"
                },
                "http://schema.org/programmingLanguage": "C, Perl",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btr509",
                        "http://schema.org/name": "(Li, 2011) A statistical framework for SNP calling, mutation discovery, association mapping and population genetical parameter estimation from sequencing data. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/21903627"
                    },
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btr076",
                        "http://schema.org/name": "(Li, 2011) Improving SNP discovery by base alignment quality. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/21320865"
                    },
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btp352",
                        "http://schema.org/name": "(Li et al., 2009) The Sequence Alignment/Map format and SAMtools. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/19505943"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://lists.sourceforge.net/lists/listinfo/samtools-help",
                    "https://lists.sourceforge.net/lists/listinfo/samtools-devel"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Sanger Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Heng Li",
                                "http://schema.org/description": "wrote most of the initial source codes of SAMtools and various converters."
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Broad Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Bob Handsaker",
                                "http://schema.org/description": "A major contributor to the\nSAM/BAM specification. He designed and implemented the BGZF format, the\nunderlying indexable compression format for the BAM format. BGZF does\nnot support arithmetic between file offsets.\n"
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Beijing Genome Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Jue Ruan",
                                "http://schema.org/description": "Designed and implemented the\nRAZF format, an alternative indexable compression format. RAZF is no longer\nused by or provided with SAMtools. Source code remains available in older\nSAMtools 0.1.x releases and from the standalone branch in the repository.\n"
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Person",
                        "http://schema.org/name": "Colin Hercus",
                        "http://schema.org/description": "updated novo2sam.pl to support gapped alignment by novoalign."
                    },
                    {
                        "class": "http://schema.org/Person",
                        "http://schema.org/name": "Petr Danecek",
                        "http://schema.org/description": "contributed the header parsing library sam_header.c and sam2vcf.pl script."
                    }
                ]
            },
            "http://schema.org/downloadUrl": "https://github.com/common-workflow-language/workflows/blob/master/tools/samtools-index.cwl",
            "http://schema.org/codeRepository": "https://github.com/common-workflow-language/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/name": "Andrey Kartashov",
                "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                "http://schema.org/sameAs": [
                    {
                        "id": "#0000-0001-9102-5681"
                    }
                ],
                "http://schema.org/worksFor": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cincinnati Children's Hospital Medical Center",
                        "http://schema.org/location": "3333 Burnet Ave, Cincinnati, OH 45229-3026",
                        "http://schema.org/department": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "Barski Lab"
                            }
                        ]
                    }
                ]
            }
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Input bam file.\n",
                    "id": "#samtools-rmdup.cwl/input"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#samtools-rmdup.cwl/output_name"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "doc": "treat PE reads as SE in rmdup (force -s)\n",
                    "id": "#samtools-rmdup.cwl/pairend_as_se"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "doc": "rmdup for SE reads\n",
                    "id": "#samtools-rmdup.cwl/single_end"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "doc": "File with removed duplicates",
                    "id": "#samtools-rmdup.cwl/rmdup"
                }
            ],
            "baseCommand": [
                "samtools",
                "rmdup"
            ],
            "doc": "samtools-rmdup.cwl is developed for CWL consortium\n",
            "id": "#samtools-rmdup.cwl",
            "http://schema.org/mainEntity": {
                "$import": "#samtools-metadata.yaml"
            },
            "http://schema.org/downloadUrl": "https://github.com/common-workflow-language/workflows/blob/master/tools/samtools-rmdup.cwl",
            "http://schema.org/codeRepository": "https://github.com/common-workflow-language/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/name": "Andrey Kartashov",
                "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                "http://schema.org/sameAs": [
                    {
                        "$import": "#0000-0001-9102-5681"
                    }
                ],
                "http://schema.org/worksFor": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cincinnati Children's Hospital Medical Center",
                        "http://schema.org/location": "3333 Burnet Ave, Cincinnati, OH 45229-3026",
                        "http://schema.org/department": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "Barski Lab"
                            }
                        ]
                    }
                ]
            }
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "doc": "Set compression level, from 0 (uncompressed) to 9 (best)\n",
                    "id": "#samtools-sort.cwl/compression_level"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Input bam file.",
                    "id": "#samtools-sort.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "doc": "Set maximum memory per thread; suffix K/M/G recognized [768M]\n",
                    "id": "#samtools-sort.cwl/memory"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 2
                    },
                    "doc": "Desired output filename.",
                    "id": "#samtools-sort.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "doc": "Sort by read names (i.e., the QNAME field) rather than by chromosomal coordinates.",
                    "id": "#samtools-sort.cwl/sort_by_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "doc": "Set number of sorting and compression threads [1]",
                    "id": "#samtools-sort.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#samtools-sort.cwl/sorted"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "doc": "samtools-sort.cwl is developed for CWL consortium\n  Usage: samtools sort [options...] [in.bam]\n  Options:\n    -l INT     Set compression level, from 0 (uncompressed) to 9 (best)\n    -m INT     Set maximum memory per thread; suffix K/M/G recognized [768M]\n    -n         Sort by read name\n    -o FILE    Write final output to FILE rather than standard output\n    -O FORMAT  Write output as FORMAT ('sam'/'bam'/'cram')   (either -O or\n    -T PREFIX  Write temporary files to PREFIX.nnnn.bam       -T is required)\n    -@ INT     Set number of sorting and compression threads [1]\n\n  Legacy usage: samtools sort [options...] <in.bam> <out.prefix>\n  Options:\n    -f         Use <out.prefix> as full final filename rather than prefix\n    -o         Write final output to stdout rather than <out.prefix>.bam\n    -l,m,n,@   Similar to corresponding options above\n",
            "id": "#samtools-sort.cwl",
            "http://schema.org/mainEntity": {
                "$import": "#samtools-metadata.yaml"
            },
            "http://schema.org/downloadUrl": "https://github.com/common-workflow-language/workflows/blob/master/tools/samtools-sort.cwl",
            "http://schema.org/codeRepository": "https://github.com/common-workflow-language/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/name": "Andrey Kartashov",
                "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                "http://schema.org/sameAs": [
                    {
                        "$import": "#0000-0001-9102-5681"
                    }
                ],
                "http://schema.org/worksFor": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cincinnati Children's Hospital Medical Center",
                        "http://schema.org/location": "3333 Burnet Ave, Cincinnati, OH 45229-3026",
                        "http://schema.org/department": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "Barski Lab"
                            }
                        ]
                    }
                ]
            }
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-L"
                    },
                    "doc": "only include reads overlapping this BED FILE [null]\n",
                    "id": "#samtools-view.cwl/bedoverlap"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-m"
                    },
                    "doc": "only include reads with number of CIGAR operations\nconsuming query sequence >= INT [0]\n",
                    "id": "#samtools-view.cwl/cigar"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-B"
                    },
                    "doc": "collapse the backward CIGAR operation\n",
                    "id": "#samtools-view.cwl/collapsecigar"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "print only the count of matching records\n",
                    "id": "#samtools-view.cwl/count"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-1"
                    },
                    "doc": "use fast BAM compression (implies -b)\n",
                    "id": "#samtools-view.cwl/fastcompression"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "Input bam file.\n",
                    "id": "#samtools-view.cwl/input"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-b"
                    },
                    "doc": "output in BAM format\n",
                    "id": "#samtools-view.cwl/isbam"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-C"
                    },
                    "doc": "output in CRAM format\n",
                    "id": "#samtools-view.cwl/iscram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-o"
                    },
                    "id": "#samtools-view.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "integer part sets seed of random number generator [0];\nrest sets fraction of templates to subsample [no subsampling]\n",
                    "id": "#samtools-view.cwl/randomseed"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "only include reads in read group STR [null]\n",
                    "id": "#samtools-view.cwl/readsingroup"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-R"
                    },
                    "doc": "only include reads with read group listed in FILE [null]\n",
                    "id": "#samtools-view.cwl/readsingroupfile"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "doc": "only include reads in library STR [null]\n",
                    "id": "#samtools-view.cwl/readsinlibrary"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "only include reads with mapping quality >= INT [0]\n",
                    "id": "#samtools-view.cwl/readsquality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "only include reads with all bits set in INT set in FLAG [0]\n",
                    "id": "#samtools-view.cwl/readswithbits"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    },
                    "doc": "only include reads with none of the bits set in INT set in FLAG [0]\n",
                    "id": "#samtools-view.cwl/readswithoutbits"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "read tag to strip (repeatable) [null]\n",
                    "id": "#samtools-view.cwl/readtagtostrip"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-T"
                    },
                    "doc": "reference sequence FASTA FILE [null]\n",
                    "id": "#samtools-view.cwl/referencefasta"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "[region ...]\n",
                    "id": "#samtools-view.cwl/region"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-h"
                    },
                    "doc": "include header in SAM output\n",
                    "id": "#samtools-view.cwl/samheader"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "number of BAM compression threads [0]\n",
                    "id": "#samtools-view.cwl/threads"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    },
                    "doc": "uncompressed BAM output (implies -b)\n",
                    "id": "#samtools-view.cwl/uncompressed"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#samtools-view.cwl/output"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "doc": "samtools-view.cwl is developed for CWL consortium\n  Usage:   samtools view [options] <in.bam>|<in.sam>|<in.cram> [region ...]\n\n  Options: -b       output BAM\n           -C       output CRAM (requires -T)\n           -1       use fast BAM compression (implies -b)\n           -u       uncompressed BAM output (implies -b)\n           -h       include header in SAM output\n           -H       print SAM header only (no alignments)\n           -c       print only the count of matching records\n           -o FILE  output file name [stdout]\n           -U FILE  output reads not selected by filters to FILE [null]\n           -t FILE  FILE listing reference names and lengths (see long help) [null]\n           -T FILE  reference sequence FASTA FILE [null]\n           -L FILE  only include reads overlapping this BED FILE [null]\n           -r STR   only include reads in read group STR [null]\n           -R FILE  only include reads with read group listed in FILE [null]\n           -q INT   only include reads with mapping quality >= INT [0]\n           -l STR   only include reads in library STR [null]\n           -m INT   only include reads with number of CIGAR operations\n                    consuming query sequence >= INT [0]\n           -f INT   only include reads with all bits set in INT set in FLAG [0]\n           -F INT   only include reads with none of the bits set in INT\n                    set in FLAG [0]\n           -x STR   read tag to strip (repeatable) [null]\n           -B       collapse the backward CIGAR operation\n           -s FLOAT integer part sets seed of random number generator [0];\n                    rest sets fraction of templates to subsample [no subsampling]\n           -@ INT   number of BAM compression threads [0]\n",
            "id": "#samtools-view.cwl",
            "http://schema.org/mainEntity": {
                "$import": "#samtools-metadata.yaml"
            },
            "http://schema.org/downloadUrl": "https://github.com/common-workflow-language/workflows/blob/master/tools/samtools-view.cwl",
            "http://schema.org/codeRepository": "https://github.com/common-workflow-language/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/name": "Andrey Kartashov",
                "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                "http://schema.org/sameAs": [
                    {
                        "$import": "#0000-0001-9102-5681"
                    }
                ],
                "http://schema.org/worksFor": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cincinnati Children's Hospital Medical Center",
                        "http://schema.org/location": "3333 Burnet Ave, Cincinnati, OH 45229-3026",
                        "http://schema.org/department": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "Barski Lab"
                            }
                        ]
                    }
                ]
            }
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
